# kasa_carbon
Show CO2 emissions of devices connected to a Kasa energy meter.

# Install instructions
This utility is installed as a python module.  Its recommended to install within a python virtual environment such as conda.  For the example below I'll be using conda. 

'''bash
conda create -n kasa python=3.12
conda activate kasa
pip install kasa-carbon





# Development instructions
You can run the project from source as 
'python -m kasa_carbon.kasa_carbon_main

